<?php

class ControllerShippingMds extends Controller {

	private $error = array();
	protected $registry;
	public $collivery;

	public function __construct($registry)
	{

		parent::__construct($registry);
		$settings = array(
			'app_name'      => "Open Cart " . VERSION,
			'app_url'       => HTTP_SERVER,
			'app_version'   => "1.0",
			'user_email'    => $this->config->get('mds_username'),
			'user_password' => $this->config->get('mds_password'),
			'demo'          => false
		);

		require_once '../system/helper/mds/Collivery.php';
		require_once '../system/helper/mds/Cache.php';
		require_once "../system/helper/mds/MdsService.php";

		$this->collivery = new \Mds\Collivery($settings);

		$this->load->language('shipping/mds');
		$data['mdsErrors'] = array();

		$this->load->model('extension/event');

		$this->install();

	}

	public function install()
	{

		$this->checkSystemRequirements();

		$this->model_extension_event->addMdsTransactionTable();

		$this->model_extension_event->addCustomAddressFields();

	}

	private function checkSystemRequirements()
	{
		$errors = array();
		if (version_compare(PHP_VERSION, '5.3.0') < 0) {
			$errors[] = 'MDS Collivery requires PHP 5.3 in order to run. Please upgrade before installing.';
		}

		if ( ! extension_loaded('soap')) {
			$errors[] = 'MDS Collivery requires SOAP to be enabled on the server. Please make sure its enabled before installing.';
		}

		if ( ! empty($errors)) {
			echo $errors;
		}
	}

	public function index()
	{
		$this->load->model('extension/event');

		$this->load->model('setting/setting');

		$this->document->setTitle($this->language->get('heading_title'));

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {

			$this->model_setting_setting->editSetting('mds', $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect(
				$this->url->link('extension/shipping', 'token=' . $this->session->data['token'], 'SSL')
			);
		}

		$data['heading_title'] = $this->language->get('heading_title');

		$data['text_edit'] = $this->language->get('text_edit');
		$data['text_enabled'] = $this->language->get('text_enabled');
		$data['text_disabled'] = $this->language->get('text_disabled');
		$data['text_yes'] = $this->language->get('text_yes');
		$data['text_no'] = $this->language->get('text_no');
		$data['text_select_all'] = $this->language->get('text_select_all');
		$data['text_unselect_all'] = $this->language->get('text_unselect_all');
		$data['text_none'] = $this->language->get('text_none');

		$data['entry_username'] = $this->language->get('entry_username');
		$data['entry_password'] = $this->language->get('entry_password');
		$data['entry_markup'] = $this->language->get('entry_markup');
		$data['entry_status'] = $this->language->get('entry_status');

		$data['entry_insurance'] = $this->language->get('entry_insurance');

		$data['entry_debug'] = $this->language->get('entry_debug');

		$data['help_username'] = $this->language->get('help_username');
		$data['help_password'] = $this->language->get('help_password');
		$data['help_markup'] = $this->language->get('help_markup');
		$data['help_insurance'] = $this->language->get('help_insurance');
		$data['help_test'] = $this->language->get('help_test');
		$data['help_debug'] = $this->language->get('help_debug');

		$data['button_save'] = $this->language->get('button_save');
		$data['button_cancel'] = $this->language->get('button_cancel');

		$services = $this->collivery->getServices();
		$data['services'] = $services;

		foreach ($services as $key => $service) {

			if (isset($this->request->post[ 'mds_serviceDisplayName' . $key ])) {
				$data[ 'mds_serviceDisplayName' . $key ] = $this->request->post[ 'mds_serviceDisplayName' . $key ];
			} else {
				if ($this->config->get('mds_serviceDisplayName' . $key) == "") {
					$data[ 'mds_serviceDisplayName' . $key ] = $service;
				} else {
					$data[ 'mds_serviceDisplayName' . $key ] = $this->config->get('mds_serviceDisplayName' . $key);
				}
			}

			if (isset($this->request->post[ 'mds_serviceSurcharge' . $key ])) {
				$data[ 'mds_serviceSurcharge' . $key ] = $this->request->post[ 'mds_serviceSurcharge' . $key ];
			} else {
				$data[ 'mds_serviceSurcharge' . $key ] = $this->config->get('mds_serviceSurcharge' . $key);
			}

		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}

		if (isset($this->error['key'])) {
			$data['error_key'] = $this->error['key'];
		} else {
			$data['error_key'] = '';
		}

		if (isset($this->error['markup'])) {
			$data['error_markup'] = $this->error['markup'];
		} else {
			$data['error_markup'] = '';
		}

		if (isset($this->error['username'])) {
			$data['error_username'] = $this->error['username'];
		} else {
			$data['error_username'] = '';
		}

		if (isset($this->error['password'])) {
			$data['error_password'] = $this->error['password'];
		} else {
			$data['error_password'] = '';
		}

		if (isset($data['mdsErrors'])) {

		} else {
			$data['mdsErrors'] = '';
		}

		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], 'SSL')
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_shipping'),
			'href' => $this->url->link('extension/shipping', 'token=' . $this->session->data['token'], 'SSL')
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('heading_title'),
			'href' => $this->url->link('shipping/mds', 'token=' . $this->session->data['token'], 'SSL')
		);

		$data['action'] = $this->url->link('shipping/mds', 'token=' . $this->session->data['token'], 'SSL');

		$data['cancel'] = $this->url->link('extension/shipping', 'token=' . $this->session->data['token'], 'SSL');

		if (isset($this->request->post['mds_username'])) {
			$data['mds_username'] = $this->request->post['mds_username'];
		} else {
			$data['mds_username'] = $this->config->get('mds_username');
		}

		if (isset($this->request->post['mds_password'])) {
			$data['mds_password'] = $this->request->post['mds_password'];
		} else {
			$data['mds_password'] = $this->config->get('mds_password');
		}

		if (isset($this->request->post['mds_markup'])) {
			$data['mds_markup'] = $this->request->post['mds_markup'];
		} else {
			$data['mds_markup'] = $this->config->get('mds_markup');
		}

		if (isset($this->request->post['mds_test'])) {
			$data['mds_test'] = $this->request->post['mds_test'];
		} else {
			$data['mds_test'] = $this->config->get('mds_test');
		}

		if (isset($this->request->post['mds_insurance'])) {
			$data['mds_insurance'] = $this->request->post['mds_insurance'];
		} else {
			$data['mds_insurance'] = $this->config->get('mds_insurance');
		}

		if (isset($this->request->post['mds_status'])) {
			$data['mds_status'] = $this->request->post['mds_status'];
		} else {
			$data['mds_status'] = $this->config->get('mds_status');
		}

		$mdsErrors = $this->collivery->getErrors();

		foreach ($mdsErrors as $mdsErrorId => $mdsError) {
			$data['mdsErrors'][ $mdsErrorId ] = array(
				'text' => $mdsError,
				'id'   => $mdsErrorId
			);
		}

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('shipping/mds.tpl', $data));

	}

	protected function validate()
	{

		if ( ! $this->user->hasPermission('modify', 'shipping/mds')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}

		if ( ! $this->request->post['mds_username']) {
			$this->error['username'] = $this->language->get('error_username');
		}

		if ( ! $this->request->post['mds_password']) {
			$this->error['password'] = $this->language->get('error_password');
		}

		if (($this->request->post['mds_username'] != $this->config->get(
					'mds_username'
				)) || ($this->request->post['mds_password'] != $this->config->get('mds_password'))
		) {

			$config = array(
				'app_name'      => "MDS Open Cart v." . VERSION,
				'app_version'   => "1.0",
				'app_host'      => 'Open Cart ' . VERSION,
				'app_url'       => HTTP_SERVER,
				'user_email'    => $this->request->post['mds_username'],
				'user_password' => $this->request->post['mds_password'],
				'demo'          => false
			);

			$this->collivery = new Mds\Collivery($config);
			$mdsErrors = $this->collivery->getErrors();

			if ($mdsErrors) {
				$this->error['warning'] = $this->language->get('error_login');
			}
		}

		return ! $this->error;
	}

}
